@@ -122,6 +122,12 @@ class MVPolyCube(mvpoly.base.MVPoly) :
         """
         return MVPolyCube(-(self.coef), dtype = self.dtype)
 
+    def __eq__(self, other) :
+        """
+        Equality of polynomials. 
+        """
+        return ((self - other).coef == 0).all()
+
     def order(self) :
         """
         Return the maximal order of each of the variables of
