@@ -59,6 +59,7 @@ class TestMVPolyCubeOrder(unittest.TestCase) :
         obtained = p.order()
         self.assertTrue(expected == obtained,
                         "bad order:\n%s" % repr(obtained))
+
     def test_order_1d(self) :
         p = MVPolyCube([1, 2, 3])
         expected = (2,)
@@ -66,7 +67,7 @@ class TestMVPolyCubeOrder(unittest.TestCase) :
         self.assertTrue(expected == obtained,
                         "bad order:\n%s" % repr(obtained))
 
-    def test_order_1d(self) :
+    def test_order_2d(self) :
         p = MVPolyCube([[1, 2, 3], [4, 5, 6]])
         expected = (1, 2)
         obtained = p.order()
@@ -74,6 +75,29 @@ class TestMVPolyCubeOrder(unittest.TestCase) :
                         "bad order:\n%s" % repr(obtained))
 
 
+class TestMVPolyCubeEqual(unittest.TestCase) :
+
+    def test_equal_self(self) :
+        p = MVPolyCube([[1, 2, 3], [4, 5, 6]])
+        self.assertTrue(p == p, "bad equality")
+
+    def test_equal_diffsize(self) :
+        p = MVPolyCube([[1, 2, 0], [4, 5, 0]])
+        q = MVPolyCube([[1, 2], [4, 5]])
+        self.assertTrue(p == q, "bad equality")
+
+    def test_equal_diffdim(self) :
+        p = MVPolyCube([[1, 2, 3], [0, 0, 0]])
+        q = MVPolyCube([1, 2, 3])
+        self.assertTrue(p == q, "bad equality")
+
+    def test_unequal(self) :
+        p = MVPolyCube([1, 2, 3])
+        q = MVPolyCube([1, 2, 3, 4])
+        self.assertFalse(p == q, "bad equality")
+        self.assertTrue(p != q, "bad equality")
+
+
 class TestMVPolyCubeAdd(unittest.TestCase) :
 
     def setUp(self) :
